@@ -372,8 +372,7 @@ class world:
         exchange.count = 0
 
         for y in range(0, self.height):
-            channel = pprocess.start(self.render_row, y)
-            exchange.add_wait(channel)
+            exchange.start(self.render_row, y)
 
         exchange.finish()
         image.save(filename)
