@@ -9,8 +9,9 @@ import time
 
 # Array size and a limit on the number of processes.
 
-N = 100
+N = 10
 limit = 10
+delay = 1
 
 def make_array(n):
 
@@ -25,7 +26,7 @@ def calculate(ch, i, j):
     process, with 'i' and 'j' as operands.
     """
 
-    time.sleep(1)
+    time.sleep(delay)
     ch.send((i, j, i * N + j))
 
 class MyExchange(pprocess.Exchange):
@@ -55,8 +56,8 @@ if __name__ == "__main__":
     print "Calculating..."
     for i in range(0, N):
         for j in range(0, N):
-            ch = pprocess.start(calculate, i, j)
-            exchange.add_wait(ch)
+            exchange.start(calculate, i, j)
+            print i, j
 
     print "Finishing..."
     exchange.finish()
